# Steamship Python Client Library

Steamship helps developers build and deploy natural language services.

**We are currently in a closed beta.** If you are interested in joining, please sign up at https://www.nludb.com/

## Installing

Install via pip:

```
pip install steamship
```

We also recommend installing the Steamship CLI for project management:

```
npm install -g @steamship/cli
```


